package org.jeecg.modules.ctop.controller;

import cn.com.ctop.common.module.entity.TagInfo;
import cn.com.ctop.common.module.model.TagInfoTreeModel;
import cn.com.ctop.common.module.service.ITagInfoService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.system.service.ISysDepartService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.List;

 /**
 * 标签信息
 * @author jeecg-boot
 * @date   2020-08-26
 * @version V1.0
 */
@Slf4j
@RestController
@RequestMapping("/ctop/tagInfo")
public class TagInfoController {
	@Autowired
	private ITagInfoService tagInfoService;

	/**
	  * 分页列表查询
	 * @param tagInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@GetMapping(value = "/list")
	public Result<IPage<TagInfo>> queryPageList(TagInfo tagInfo,
												@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
												@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
												HttpServletRequest req) {
		Result<IPage<TagInfo>> result = new Result<>();
		QueryWrapper<TagInfo> queryWrapper = QueryGenerator.initQueryWrapper(tagInfo, req.getParameterMap());
		Page<TagInfo> page = new Page<>(pageNo, pageSize);
		IPage<TagInfo> pageList = tagInfoService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param tagInfo
	 * @return
	 */
	@PostMapping(value = "/add")
	public Result<TagInfo> add(@RequestBody TagInfo tagInfo) {
		Result<TagInfo> result = new Result<>();
		try {
			tagInfoService.save(tagInfo);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param tagInfo
	 * @return
	 */
	@PutMapping(value = "/edit")
	public Result<TagInfo> edit(@RequestBody TagInfo tagInfo) {
		Result<TagInfo> result = new Result<TagInfo>();
		TagInfo tagInfoEntity = tagInfoService.getById(tagInfo.getId());
		if(tagInfoEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = tagInfoService.updateById(tagInfo);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			tagInfoService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@DeleteMapping(value = "/deleteBatch")
	public Result<TagInfo> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<TagInfo> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.tagInfoService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@GetMapping(value = "/queryById")
	public Result<TagInfo> queryById(@RequestParam(name="id",required=true) String id) {
		Result<TagInfo> result = new Result<>();
		TagInfo tagInfo = tagInfoService.getById(id);
		if(tagInfo==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(tagInfo);
			result.setSuccess(true);
		}
		return result;
	}

	@Autowired
    private ISysDepartService sysDepartService;
	@RequestMapping(value = "/queryTreeList", method = RequestMethod.GET)
    public Result<List<TagInfoTreeModel>> queryTreeList() {
	    Result<List<TagInfoTreeModel>> result = new Result<>();
	    try {
            List<TagInfoTreeModel> list = tagInfoService.queryTreeList();
	        result.setResult(list);
	        result.setSuccess(true);
	    } catch (Exception e) {
	        log.error(e.getMessage(),e);
	    }
	    return result;
	}
}
