package cn.com.ctop.common.module.service.impl;

import cn.com.ctop.common.module.entity.Advertiser;
import cn.com.ctop.common.module.entity.Product;
import cn.com.ctop.common.module.entity.Project;
import cn.com.ctop.common.module.mapper.ProductMapper;
import cn.com.ctop.common.module.service.IProductService;
import cn.com.ctop.common.module.vo.*;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.ibatis.annotations.Param;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service
public class ProductServiceImpl extends ServiceImpl<ProductMapper, Product> implements IProductService {

    @Autowired
    private ProductMapper productMapper;

    @Override
    public List<Advertiser> advertiserList(){
        return productMapper.getAdvertiserList();
    }

    @Override
    public List<Project> getProjectListByAdvertiserId(String advertiserId){
        return productMapper.getProjectListByAdvertiserId(advertiserId);
    }

    @Override
    public Map<String,Object> getSaleAndYunyingListByProjectIds(List<Long> projectIds){
        Map<String,Object> map = new HashMap<>();

        List<ProductDto> saleList = productMapper.getSaleListByProjectIds(projectIds);
        List<ProductDto> yunyingeList = productMapper.getYunyingListByProjectIds(projectIds);

        map.put("saleList",saleList);
        map.put("yunyingList",yunyingeList);

        return map;
    }

    @Override
    public void deleteProduct(Long id){
        productMapper.logicDeleteProductById(id);
    }

    @Override
    public void insertOrUpdateProduct(ProductVO product){
        //更新
        if(product.getId() != null){
            //productMapper.deleteProductProjectMapByProductId(product.getId());
            //if(product.getProjectIds() != null && product.getProjectIds().size() != 0 ){
            //    productMapper.insertProductProjectMap(product.getProjectIds(), product.getId());
            //}
            productMapper.updateProduct(product);
        }else { //入库
            LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
            product.setCreateUserId(sysUser.getId());
            productMapper.insertProduct(product);

            if(product.getProjectIds() != null && product.getProjectIds().size() != 0 ){
                productMapper.insertProductProjectMap(product.getProjectIds(), product.getId());
            }
        }
    }

    @Override
    public Integer getProductNameCount(String productName){
        return productMapper.getProductNameCount(productName);
    }

    @Override
    public void insertProductProjectMap(Long productId, List<Long> projectIds){
        productMapper.insertProductProjectMap(projectIds, productId);
    }

  @Override
    public Map<String, Object> getProductInfo(Long productId){
        Map<String,Object> map = new HashMap<>();

        Product product = productMapper.getProductInfo(productId);
        List<ProjectVO> projectList = productMapper.getProjectListByProductId(productId);

        List<Long> projectIds = new ArrayList<>();
        for(ProjectVO vo:projectList){
            projectIds.add(vo.getProjectId());
        }

        List<ProductDto> saleList = productMapper.getSaleListByProjectIds(projectIds);
        List<ProductDto> yunyingeList = productMapper.getYunyingListByProjectIds(projectIds);

        map.put("saleList",saleList);
        map.put("yunyingList",yunyingeList);
        map.put("product",product);
        map.put("projectList",projectList);

        return map;
    }

    @Override
    public void deleteByProjectIdAndProductId(Long projectId, Long productId){
        productMapper.deleteByProjectIdAndProductId(productId, projectId);
    }

    @Override
    public List<ProjectVO> getProjectListByProductId(Long productId){
        return productMapper.getProjectListByProductId(productId);
    }

    @Override
    public PageInfo<ProductVO> getProductList(String advertiserName, String productName, Integer pageNum, Integer pageSize){
        PageHelper.startPage(pageNum, pageSize);
        List<ProductVO> productList = productMapper.getProductList(advertiserName, productName);

        for(ProductVO product:productList){
            List<ProjectVO> projectListByProductId = productMapper.getProjectListByProductId(product.getId());
            List<SaleVO> salesListByProductId = productMapper.getSalesListByProductId(product.getId());
            List<UserDto> yunyingListByProductId = productMapper.getYunyingListByProductId(product.getId());
            List<Long> projectIds = productMapper.getProjectIdsByProductId(product.getId());

            product.setProjectIds(projectIds);
            product.setProjectList(projectListByProductId);
            product.setSaleList(salesListByProductId);
            product.setYunyingList(yunyingListByProductId);
        }

        return new PageInfo<>(productList);

    }

    @Override
    public List<Long> getProjectIdsByProductId(Long productId){

        return productMapper.getProjectIdsByProductId(productId);

    }






}
